@@ -59,16 +59,16 @@ def test_idempotence_execute(  # type: ignore[no-untyped-def]  # noqa: ANN201, D
     _patched_is_idempotent: Mock,  # noqa: PT019
     _instance,  # noqa: PT019
 ):
-    with caplog.at_level(logging.INFO, logger="molecule.molecule.logger"):
-        _instance.execute()
+    _instance._config.action = "idempotence"
+    i = idempotence.Idempotence(_instance._config)
 
-    # Check that we have log records with scenario and step information
-    assert any(
-        hasattr(record, "molecule_scenario")
-        and hasattr(record, "molecule_step")
-        and record.molecule_step == "idempotence"
-        for record in caplog.records
-    )
+    with caplog.at_level(logging.INFO):
+        i.execute()
+
+    expected_record_count = 2
+    assert len(caplog.records) == expected_record_count
+    expected_message = "INFO     [default > idempotence] Executed: Successful"
+    assert caplog.records[1].getMessage() == expected_message
 
     patched_ansible_converge.assert_called_once_with()
 
