@@ -67,14 +67,38 @@ def _patched_link_or_update_vars(mocker: MockerFixture) -> MagicMock:
 @pytest.fixture
 def _provisioner_section_data():  # type: ignore[no-untyped-def]  # noqa: ANN202
     return {
-        "provisioner": {
-            "name": "ansible",
-            "config_options": {"defaults": {"foo": "bar"}},
-            "connection_options": {"foo": "bar"},
-            "options": {"foo": "bar", "become": True, "v": True},
+        "dependency": {"name": "galaxy"},
+        "driver": {"name": "default", "options": {"managed": True}},
+        "platforms": [
+            {"name": "instance-1", "groups": ["foo", "bar"], "children": ["child1"]},
+            {"name": "instance-2", "groups": ["baz", "foo"], "children": ["child2"]},
+        ],
+        "ansible": {
+            "cfg": {"defaults": {"foo": "bar"}},
             "env": {
                 "FOO": "bar",
             },
+            "executor": {
+                "backend": "ansible-playbook",
+                "args": {
+                    "ansible_navigator": [],
+                    "ansible_playbook": [],
+                },
+            },
+            "playbooks": {
+                "cleanup": "cleanup.yml",
+                "create": "create.yml",
+                "converge": "converge.yml",
+                "destroy": "destroy.yml",
+                "prepare": "prepare.yml",
+                "side_effect": "side_effect.yml",
+                "verify": "verify.yml",
+            },
+        },
+        "provisioner": {
+            "name": "ansible",
+            "connection_options": {"foo": "bar"},
+            "options": {"foo": "bar", "become": True, "v": True},
             "inventory": {
                 "hosts": {
                     "all": {
@@ -92,6 +116,8 @@ def _provisioner_section_data():  # type: ignore[no-untyped-def]  # noqa: ANN202
                 },
             },
         },
+        "scenario": {"name": "default"},
+        "verifier": {"name": "ansible"},
     }
 
 
@@ -106,6 +132,7 @@ def fixture_instance(
         _provisioner_section_data: A dictionary containing the provisioner section data.
         config_instance: An instance of a Molecule config.
     """
+    config_instance.scenario.results.add_action_result("verify")
     return ansible.Ansible(config_instance)
 
 
@@ -273,30 +300,6 @@ def test_inventory_directory_property(instance: Ansible) -> None:
     assert str(x) == instance.inventory_directory
 
 
-def test_inventory_directory_property_shared(instance: Ansible) -> None:
-    """Test the shared_inventory_directory property.
-
-    Args:
-        instance: Ansible provisioner instance.
-    """
-    instance._config.command_args["shared_inventory"] = True
-    x = Path(instance._config.scenario.shared_ephemeral_directory, "inventory")
-    assert str(x) == instance.inventory_directory
-
-
-def test_inventory_directory_property_shared_parallel(instance: Ansible) -> None:
-    """Test the shared_inventory_directory property with parallel mode on.
-
-    Args:
-        instance: Ansible provisioner instance.
-    """
-    instance._config.command_args["shared_inventory"] = True
-    instance._config.command_args["parallel"] = True
-    # Parallel disables shared ephemeral directory
-    x = Path(instance._config.scenario.ephemeral_directory, "inventory")
-    assert str(x) == instance.inventory_directory
-
-
 def test_inventory_file_property(instance):  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
     x = os.path.join(  # noqa: PTH118
         instance._config.scenario.inventory_directory,
@@ -740,20 +743,6 @@ def test_verify_inventory(instance):  # type: ignore[no-untyped-def]  # noqa: AN
     instance._verify_inventory()
 
 
-def test_verify_inventory_raises_when_missing_hosts(  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
-    caplog,
-    instance,
-):
-    instance._config.config["platforms"] = []
-    with pytest.raises(MoleculeError) as e:
-        instance._verify_inventory()
-
-    assert e.value.code == 1
-
-    msg = "Instances missing from the 'platform' section of molecule.yml."
-    assert msg in caplog.text
-
-
 def test_vivify(instance):  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
     d = instance._vivify()
     d["bar"]["baz"] = "qux"
@@ -793,3 +782,113 @@ def test_absolute_path_for_raises_with_missing_key(instance):  # type: ignore[no
 
     with pytest.raises(KeyError):
         instance._absolute_path_for(env, "invalid")
+
+
+# Test ansible section integration with provisioner
+
+
+def test_ansible_args_property_with_ansible_playbook_backend() -> None:
+    """Test ansible_args property with ansible-playbook backend (forward-looking config)."""
+    c = config.Config(molecule_file="")
+    c.config = {
+        "ansible": {
+            "executor": {
+                "backend": "ansible-playbook",
+                "args": {"ansible_playbook": ["--forks=20"], "ansible_navigator": []},
+            },
+            "cfg": {},
+            "env": {},
+            "playbooks": {},
+        },
+        "provisioner": {"name": "ansible"},
+        "driver": {"name": "default"},
+        "platforms": [],
+    }
+
+    instance = ansible.Ansible(c)
+    assert instance.ansible_args == ["--forks=20"]
+
+
+def test_ansible_args_property_with_ansible_navigator_backend() -> None:
+    """Test ansible_args property with ansible-navigator backend (forward-looking config)."""
+    c = config.Config(molecule_file="")
+    c.config = {
+        "ansible": {
+            "executor": {
+                "backend": "ansible-navigator",
+                "args": {
+                    "ansible_navigator": ["--mode=stdout"],
+                    "ansible_playbook": ["--forks=10"],
+                },
+            },
+            "cfg": {},
+            "env": {},
+            "playbooks": {},
+        },
+        "provisioner": {"name": "ansible"},
+        "driver": {"name": "default"},
+        "platforms": [],
+    }
+
+    instance = ansible.Ansible(c)
+    # Should get navigator args + ["--"] + playbook args
+    assert instance.ansible_args == ["--mode=stdout", "--", "--forks=10"]
+
+
+def test_config_options_property_uses_forward_looking_config() -> None:
+    """Test config_options property with forward-looking ansible config structure."""
+    c = config.Config(molecule_file="")
+    c.config = {
+        "ansible": {
+            "cfg": {"defaults": {"deprecation_warnings": False}},
+            "executor": {
+                "backend": "ansible-playbook",
+                "args": {"ansible_playbook": [], "ansible_navigator": []},
+            },
+            "env": {},
+            "playbooks": {},
+        },
+        "provisioner": {"name": "ansible"},
+        "driver": {"name": "default"},
+        "platforms": [],
+    }
+
+    instance = ansible.Ansible(c)
+    result = instance.config_options
+
+    # Should get the ansible.cfg value merged with defaults
+    assert result["defaults"]["deprecation_warnings"] is False
+    # Should still have default config options
+    assert "forks" in result["defaults"]
+    assert "host_key_checking" in result["defaults"]
+
+
+def test_config_options_property_merges_ansible_cfg_with_base() -> None:
+    """Test config_options property merges ansible.cfg with base config."""
+    c = config.Config(molecule_file="")
+    c.config = {
+        "ansible": {
+            "cfg": {
+                "defaults": {"deprecation_warnings": False},
+                "ssh_connection": {"scp_if_ssh": True},
+            },
+            "executor": {
+                "backend": "ansible-playbook",
+                "args": {"ansible_playbook": [], "ansible_navigator": []},
+            },
+            "env": {},
+            "playbooks": {},
+        },
+        "provisioner": {"name": "ansible"},
+        "driver": {"name": "default"},
+        "platforms": [],
+    }
+
+    instance = ansible.Ansible(c)
+    result = instance.config_options
+
+    # Should have ansible.cfg settings merged with defaults
+    assert result["defaults"]["deprecation_warnings"] is False
+    assert result["ssh_connection"]["scp_if_ssh"] is True
+    # Should still have default config options merged in
+    assert "forks" in result["defaults"]
